======================
t-desktop
======================

t-desktop is a Python library that provides common methods for desktop automation, simplifying tasks like window management, keyboard, and mouse control.
